@@ -1,3 +1,8 @@
+#!/usr/bin/env bash
+
+# This package should be tested under python 3, when the job enables Python 3
+enable_python3_package ironic-inspector
+
 IRONIC_INSPECTOR_DEBUG=${IRONIC_INSPECTOR_DEBUG:-True}
 IRONIC_INSPECTOR_DIR=$DEST/ironic-inspector
 IRONIC_INSPECTOR_DATA_DIR=$DATA_DIR/ironic-inspector
@@ -11,7 +16,29 @@ IRONIC_INSPECTOR_DHCP_CONF_FILE=$IRONIC_INSPECTOR_CONF_DIR/dnsmasq.conf
 IRONIC_INSPECTOR_ROOTWRAP_CONF_FILE=$IRONIC_INSPECTOR_CONF_DIR/rootwrap.conf
 IRONIC_INSPECTOR_ADMIN_USER=${IRONIC_INSPECTOR_ADMIN_USER:-ironic-inspector}
 IRONIC_INSPECTOR_AUTH_CACHE_DIR=${IRONIC_INSPECTOR_AUTH_CACHE_DIR:-/var/cache/ironic-inspector}
-IRONIC_INSPECTOR_MANAGE_FIREWALL=$(trueorfalse True IRONIC_INSPECTOR_MANAGE_FIREWALL)
+IRONIC_INSPECTOR_DHCP_FILTER=${IRONIC_INSPECTOR_DHCP_FILTER:-iptables}
+if [[ -n ${IRONIC_INSPECTOR_MANAGE_FIREWALL} ]] ; then
+    echo "IRONIC_INSPECTOR_MANAGE_FIREWALL is deprecated." >&2
+    echo "Please, use IRONIC_INSPECTOR_DHCP_FILTER == noop/iptables/dnsmasq instead." >&2
+    if [[ "$IRONIC_INSPECTOR_DHCP_FILTER" != "iptables" ]] ; then
+        # both manage firewall and filter driver set together but driver isn't iptables
+        echo "Inconsistent configuration: IRONIC_INSPECTOR_MANAGE_FIREWALL used while" >&2
+        echo "IRONIC_INSPECTOR_DHCP_FILTER == $IRONIC_INSPECTOR_DHCP_FILTER" >&2
+        exit 1
+    fi
+    if [[ $(trueorfalse True IRONIC_INSPECTOR_MANAGE_FIREWALL) == "False" ]] ; then
+        echo "IRONIC_INSPECTOR_MANAGE_FIREWALL == False" >&2
+        echo "Setting IRONIC_INSPECTOR_DHCP_FILTER=noop" >&2
+        IRONIC_INSPECTOR_DHCP_FILTER=noop
+    fi
+fi
+
+# dnsmasq dhcp filter configuration
+# override the default hostsdir so devstack collects the MAC files (/etc)
+IRONIC_INSPECTOR_DHCP_HOSTSDIR=${IRONIC_INSPECTOR_DHCP_HOSTSDIR:-/etc/ironic-inspector/dhcp-hostsdir}
+IRONIC_INSPECTOR_DNSMASQ_STOP_COMMAND=${IRONIC_INSPECTOR_DNSMASQ_STOP_COMMAND:-systemctl stop devstack@ironic-inspector-dhcp}
+IRONIC_INSPECTOR_DNSMASQ_START_COMMAND=${IRONIC_INSPECTOR_DNSMASQ_START_COMMAND:-systemctl start devstack@ironic-inspector-dhcp}
+
 IRONIC_INSPECTOR_HOST=$HOST_IP
 IRONIC_INSPECTOR_PORT=5050
 IRONIC_INSPECTOR_URI="http://$IRONIC_INSPECTOR_HOST:$IRONIC_INSPECTOR_PORT"
@@ -50,7 +77,11 @@ function mkdir_chown_stack {
 }
 
 function inspector_iniset {
-    iniset "$IRONIC_INSPECTOR_CONF_FILE" $1 $2 $3
+    local section=$1
+    local option=$2
+    shift 2
+    # value in iniset is at $4; wrapping in quotes
+    iniset "$IRONIC_INSPECTOR_CONF_FILE" $section $option "$*"
 }
 
 ### Install-start-stop
@@ -76,6 +107,11 @@ function start_inspector {
     run_process ironic-inspector "$IRONIC_INSPECTOR_CMD"
 }
 
+function is_inspector_dhcp_required {
+    [[ "$IRONIC_INSPECTOR_MANAGE_FIREWALL" == "True" ]] || \
+    [[ "${IRONIC_INSPECTOR_DHCP_FILTER:-iptables}" != "noop" ]]
+}
+
 function start_inspector_dhcp {
     # NOTE(dtantsur): USE_SYSTEMD requires an absolute path
     run_process ironic-inspector-dhcp \
@@ -162,6 +198,47 @@ function inspector_configure_auth_for {
     inspector_iniset $1 os_region $REGION_NAME
 }
 
+function is_dnsmasq_filter_required {
+    [[ "$IRONIC_INSPECTOR_DHCP_FILTER" == "dnsmasq" ]]
+}
+
+function configure_inspector_pxe_filter_dnsmasq {
+    mkdir_chown_stack $IRONIC_INSPECTOR_DHCP_HOSTSDIR
+    inspector_iniset pxe_filter driver dnsmasq
+    inspector_iniset dnsmasq_pxe_filter dhcp_hostsdir $IRONIC_INSPECTOR_DHCP_HOSTSDIR
+    inspector_iniset dnsmasq_pxe_filter dnsmasq_stop_command "$IRONIC_INSPECTOR_DNSMASQ_STOP_COMMAND"
+    inspector_iniset dnsmasq_pxe_filter dnsmasq_start_command "$IRONIC_INSPECTOR_DNSMASQ_START_COMMAND"
+}
+
+function configure_dnsmasq_dhcp_hostsdir {
+    sed -ie '/dhcp-hostsdir.*=/d' $IRONIC_INSPECTOR_DHCP_CONF_FILE
+    echo "dhcp-hostsdir=$IRONIC_INSPECTOR_DHCP_HOSTSDIR" >> $IRONIC_INSPECTOR_DHCP_CONF_FILE
+}
+
+function _dnsmasq_rootwrap_ctl_tail {
+    # cut off the command head and amend white-spaces with commas
+    shift
+    local bits=$*
+    echo ${bits//\ /, }
+}
+
+function configure_inspector_dnsmasq_rootwrap {
+    # turn the ctl commands into filter rules and dump the roorwrap file
+    local stop_cmd=( $IRONIC_INSPECTOR_DNSMASQ_STOP_COMMAND )
+    local start_cmd=( $IRONIC_INSPECTOR_DNSMASQ_START_COMMAND )
+
+    local stop_cmd_tail=$( _dnsmasq_rootwrap_ctl_tail ${stop_cmd[@]} )
+    local start_cmd_tail=$( _dnsmasq_rootwrap_ctl_tail ${start_cmd[@]} )
+
+    cat > "$IRONIC_INSPECTOR_CONF_DIR/rootwrap.d/ironic-inspector-dnsmasq.filters" <<EOF
+[Filters]
+# ironic_inspector/pxe_filter/dnsmasq.py
+${stop_cmd[0]}: CommandFilter, ${stop_cmd[0]}, root, ${stop_cmd_tail}
+${start_cmd[0]}: CommandFilter, ${start_cmd[0]}, root, ${start_cmd_tail}
+EOF
+
+}
+
 function configure_inspector {
     mkdir_chown_stack "$IRONIC_INSPECTOR_CONF_DIR"
     mkdir_chown_stack "$IRONIC_INSPECTOR_DATA_DIR"
@@ -176,11 +253,14 @@ function configure_inspector {
     inspector_iniset DEFAULT listen_port $IRONIC_INSPECTOR_PORT
     inspector_iniset DEFAULT listen_address 0.0.0.0  # do not change
 
-    inspector_iniset firewall manage_firewall $IRONIC_INSPECTOR_MANAGE_FIREWALL
-    inspector_iniset firewall dnsmasq_interface $IRONIC_INSPECTOR_INTERFACE
+    inspector_iniset pxe_filter driver $IRONIC_INSPECTOR_DHCP_FILTER
+    inspector_iniset iptables dnsmasq_interface $IRONIC_INSPECTOR_INTERFACE
     inspector_iniset database connection `database_connection_url ironic_inspector`
 
-    is_service_enabled swift && configure_inspector_swift
+    # FIXME(ankit) Remove this when swift supports python3
+    if [[ "$USE_PYTHON3" == "False" ]] && is_service_enabled swift; then
+        configure_inspector_swift
+    fi
 
     iniset "$IRONIC_CONF_FILE" inspector enabled True
     iniset "$IRONIC_CONF_FILE" inspector service_url $IRONIC_INSPECTOR_URI
@@ -215,6 +295,11 @@ function configure_inspector {
     get_or_create_endpoint "baremetal-introspection" "$REGION_NAME" \
         "$IRONIC_INSPECTOR_URI" "$IRONIC_INSPECTOR_URI" "$IRONIC_INSPECTOR_URI"
 
+    if is_dnsmasq_filter_required ; then
+        configure_inspector_dnsmasq_rootwrap
+        configure_inspector_pxe_filter_dnsmasq
+    fi
+
 }
 
 function configure_inspector_swift {
@@ -248,6 +333,10 @@ dhcp-boot=pxelinux.0
 dhcp-sequential-ip
 EOF
     fi
+
+    if is_dnsmasq_filter_required ; then
+        configure_dnsmasq_dhcp_hostsdir
+    fi
 }
 
 function prepare_environment {
@@ -290,7 +379,7 @@ function cleanup_inspector {
     sudo rm -rf $IRONIC_INSPECTOR_AUTH_CACHE_DIR
     sudo rm -rf "$IRONIC_INSPECTOR_RAMDISK_LOGDIR"
 
-    # Try to clean up firewall rules
+    # Always try to clean up firewall rules, no matter filter driver used
     sudo iptables -D INPUT -i $IRONIC_INSPECTOR_INTERFACE -p udp \
         --dport 69 -j ACCEPT | true
     sudo iptables -D INPUT -i $IRONIC_INSPECTOR_INTERFACE -p tcp \
@@ -316,7 +405,7 @@ function sync_inspector_database {
 
 if [[ "$1" == "stack" && "$2" == "install" ]]; then
     echo_summary "Installing ironic-inspector"
-    if [[ "$IRONIC_INSPECTOR_MANAGE_FIREWALL" == "True" ]]; then
+    if is_inspector_dhcp_required; then
         install_inspector_dhcp
     fi
     install_inspector
@@ -324,7 +413,7 @@ if [[ "$1" == "stack" && "$2" == "install" ]]; then
 elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
     echo_summary "Configuring ironic-inspector"
     cleanup_inspector
-    if [[ "$IRONIC_INSPECTOR_MANAGE_FIREWALL" == "True" ]]; then
+    if is_inspector_dhcp_required; then
         configure_inspector_dhcp
     fi
     configure_inspector
@@ -332,7 +421,7 @@ elif [[ "$1" == "stack" && "$2" == "post-config" ]]; then
 elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
     echo_summary "Initializing ironic-inspector"
     prepare_environment
-    if [[ "$IRONIC_INSPECTOR_MANAGE_FIREWALL" == "True" ]]; then
+    if is_inspector_dhcp_required; then
         start_inspector_dhcp
     fi
     start_inspector
@@ -348,7 +437,7 @@ fi
 
 if [[ "$1" == "unstack" ]]; then
     stop_inspector
-    if [[ "$IRONIC_INSPECTOR_MANAGE_FIREWALL" == "True" ]]; then
+    if is_inspector_dhcp_required; then
         stop_inspector_dhcp
     fi
     cleanup_inspector
